Struct IntegerParameter

pub struct IntegerParameter {
    pub(crate) name: CapeStringImpl,
    description: CapeStringImpl,
    is_input: bool,
    shared_unit_data: Rc<RefCell<SharedUnitData>>,
    pub(crate) value: i32,
    default_value: i32,
    minimum_value: i32,
    maximum_value: i32,
    cobia_object_data: IntegerParameterCobiaObjectData,
}
The IntegerParameter class implements a CAPE-OPEN 1.2 integer parameter.

Parameters must implement the ICapeIdentification and ICapeParameter interfaces. In addition, integer parameters must implement the ICapeIntegerParameter interface.

This implementation can be used for both input and output parameters. Input parameters can be set by the user, while output parameters are set by the unit operation.

Although CAPE-OPEN defines a value for an integer that is not specified (the equivalent of NaN for real values), this value is not widely supported, and unspecified values are not allowed in this implementation.

Any invalid values (outside the bounds of the parameter) will raise an error when set. Therefore, any parameter is valid.

Fields

name: CapeStringImpl

The name of the parameter

description: CapeStringImpl

The description of the parameter

is_input: bool

Indicates whether this parameter is an input (true) or an output (false)

shared_unit_data: Rc<RefCell<SharedUnitData>>

Shared data for the unit, containing unit-specific information

value: i32

The current value of the parameter

default_value: i32

Default value of the parameter

minimum_value: i32

Minimum value of the parameter

maximum_value: i32

Maximum value of the parameter

cobia_object_data: IntegerParameterCobiaObjectData

Cobia object data for this object, which contains generated code to provide the native COBIA interfaces

Implementations

Source

impl IntegerParameter

fn create_instance( _integer_parameter_boxed_ptr: *mut *mut ICapeInterface, name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: i32, minimum_value: i32, maximum_value: i32, ) -> CapeResult

pub(crate) fn create<T: CapeSmartPointer>( name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: i32, minimum_value: i32, maximum_value: i32, ) -> T

Create a new instance of the object and return a smart pointer to it

This function panics if the created object does not implement the interface corresponding to the smart pointer to be returned. For a non-panic version, use the try_create() function.

pub(crate) fn try_create<T: CapeSmartPointer>( name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: i32, minimum_value: i32, maximum_value: i32, ) -> Result<T, COBIAError>

Create a new instance of the object and return a smart pointer to it

This function returns an error if the created object does not implement the interface corresponding to the smart pointer to be returned.

pub(crate) unsafe fn borrow<T: CapeSmartPointer>(smart_pointer: &T) -> &Self

Get a reference to the object

Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows

Safety

The user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.

pub(crate) unsafe fn borrow_mut<T: CapeSmartPointer>( smart_pointer: &mut T, ) -> &mut Self

Get a mutable reference to the object

Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows

Safety

This function is unsafe because it allows mutable access to the object. Also the user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.

Source

impl IntegerParameter

fn new( name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: i32, minimum_value: i32, maximum_value: i32, ) -> Self